[![Build Status](https://travis-ci.org/suguby/robogame_engine.svg?branch=master)](https://travis-ci.org/suguby/robogame_engine)
[![PyPi version](https://pypip.in/version/robogame_engine/badge.png)](https://pypi.python.org/pypi/robogame_engine/)
### Robo Game Engine

The package allows you to create RoboGames with python. As example see https://github.com/suguby/astrobox
